@@ -3,7 +3,7 @@ package Nmap::Parser;
 use strict;
 use XML::Twig;
 
-our $VERSION = 1.32;
+our $VERSION = 1.33;
 
 
 sub new {
@@ -383,6 +383,10 @@ sub __host_port_tag_hdlr {
           || 'unknown'
           if ( $state ne '' );
 
+        $port_hashref->{$proto}{$portid}{reason_ttl} = $state->{att}->{reason_ttl}
+          || 'unknown'
+          if($state ne '');
+
         #GET SERVICE INFORMATION
         $port_hashref->{$proto}{$portid}{service} =
           __host_service_tag_hdlr( $port_tag, $portid )
@@ -878,6 +882,15 @@ sub _get_port_state {
 
 }
 
+sub _get_port_state_ttl {
+    my $self = shift;
+    my $proto = pop;
+    my $portid = lc(shift);
+
+    return undef unless ( exists $self->{ports}{$proto}{$portid} );
+    return $self->{ports}{$proto}{$portid}{reason_ttl};
+}
+
 #changed this to use _get_ports since it was similar code
 sub tcp_ports { return _get_ports( @_, 'tcp' ); }
 sub udp_ports { return _get_ports( @_, 'udp' ); }
@@ -885,6 +898,8 @@ sub udp_ports { return _get_ports( @_, 'udp' ); }
 sub tcp_port_count { return $_[0]->{ports}{tcp_port_count}; }
 sub udp_port_count { return $_[0]->{ports}{udp_port_count}; }
 
+sub tcp_port_state_ttl { return _get_port_state_ttl( @_, 'tcp' ); }
+
 sub tcp_port_state { return _get_port_state( @_, 'tcp' ); }
 sub udp_port_state { return _get_port_state( @_, 'udp' ); }
 
@@ -1140,7 +1155,7 @@ Nmap::Parser - parse nmap scan data with perl
 
 
 I<For a full listing of methods see the documentation corresponding to each object.>
-You can also visit the website L<https://modernistik.github.io/Nmap-Parser/> for additional installation instructions.
+You can also visit the website L<https://github.com/modernistik/Nmap-Parser> for additional installation instructions.
 
 =head1 DESCRIPTION
 
@@ -1149,7 +1164,7 @@ It is implemented by parsing the xml scan data that is generated by nmap. This
 will enable anyone who utilizes nmap to quickly create fast and robust security scripts
 that utilize the powerful port scanning abilities of nmap.
 
-The latest version of this module can be found on here L<https://modernistik.github.io/Nmap-Parser/>
+The latest version of this module can be found on here L<https://github.com/modernistik/Nmap-Parser>
 
 =head1 OVERVIEW
 
@@ -1345,10 +1360,10 @@ Returns the version of nmap xml file.
 
 A basic call to prescripts() returns a list of the names of the NSE scripts
 run in the pre-scanning phase. If C<$name> is given, it returns the text output of the
-a reference to a hash with "output" and "content" keys for the
+a reference to a hash with "output" and "contents" keys for the
 script with that name, or undef if that script was not run.
 The value of the "output" key is the text output of the script. The value of the
-"content" key is a data structure based on the XML output of the NSE script.
+"contents" key is a data structure based on the XML output of the NSE script.
 
 =item B<postscripts()>
 
@@ -1356,10 +1371,10 @@ The value of the "output" key is the text output of the script. The value of the
 
 A basic call to postscripts() returns a list of the names of the NSE scripts
 run in the post-scaning phase. If C<$name> is given, it returns the text output of the
-a reference to a hash with "output" and "content" keys for the
+a reference to a hash with "output" and "contents" keys for the
 script with that name, or undef if that script was not run.
 The value of the "output" key is the text output of the script. The value of the
-"content" key is a data structure based on the XML output of the NSE script.
+"contents" key is a data structure based on the XML output of the NSE script.
 
 =back
 
@@ -1500,10 +1515,10 @@ when the scan was performed.
 
 A basic call to hostscripts() returns a list of the names of the host scripts
 run. If C<$name> is given, it returns the text output of the
-a reference to a hash with "output" and "content" keys for the
+a reference to a hash with "output" and "contents" keys for the
 script with that name, or undef if that script was not run.
 The value of the "output" key is the text output of the script. The value of the
-"content" key is a data structure based on the XML output of the NSE script.
+"contents" key is a data structure based on the XML output of the NSE script.
 
 =item B<tcp_ports()>
 
@@ -1524,6 +1539,10 @@ be counted as an 'open' port as well as a 'filtered' one.>
 
 Returns the total of TCP|UDP ports scanned respectively.
 
+=item B<tcp_port_state_ttl()>
+
+Returns the 'reason_ttl' value present in nmap xml result.
+
 =item B<tcp_del_ports($portid, [$portid, ...])>
 
 =item B<udp_del_ports($portid, [ $portid, ...])>
@@ -1636,10 +1655,10 @@ Returns the version of the given product of the running service.
 
 A basic call to scripts() returns a list of the names of the NSE scripts
 run for this port. If C<$name> is given, it returns
-a reference to a hash with "output" and "content" keys for the
+a reference to a hash with "output" and "contents" keys for the
 script with that name, or undef if that script was not run.
 The value of the "output" key is the text output of the script. The value of the
-"content" key is a data structure based on the XML output of the NSE script.
+"contents" key is a data structure based on the XML output of the NSE script.
 
 =back
 
@@ -1776,7 +1795,7 @@ The host name of this hop, if known.
 I think some of us best learn from examples. These are a couple of examples to help
 create custom security audit tools using some of the nice features
 of the Nmap::Parser module. Hopefully this can double as a tutorial.
-More tutorials (articles) can be found at L<https://modernistik.github.io/Nmap-Parser/>
+More tutorials (articles) can be found at L<https://github.com/modernistik/Nmap-Parser>
 
 =head2 Real-Time Scanning
 
@@ -1884,12 +1903,12 @@ same hosts, and compare if any new tcp have been open since then
 
 If you have questions about how to use the module, or any of its features, you
 can post messages to the Nmap::Parser module forum on CPAN::Forum.
-L<https://github.com/modernistik/nmap-parser/issues>
+L<https://github.com/modernistik/Nmap-Parser/issues>
 
 =head2 Bug Reports, Enhancements, Merge Requests
 
 Please submit any bugs or feature requests to:
-L<https://github.com/modernistik/nmap-parser/issues>
+L<https://github.com/modernistik/Nmap-Parser/issues>
 
 B<Please make sure that you submit the xml-output file of the scan which you are having
 trouble with.> This can be done by running your scan with the I<-oX filename.xml> nmap switch.
@@ -1899,7 +1918,7 @@ Please remove any important IP addresses for security reasons. It saves time in
 
  nmap, XML::Twig
 
-The Nmap::Parser page can be found at: L<https://github.com/modernistik/nmap-parser>.
+The Nmap::Parser page can be found at: L<https://github.com/modernistik/Nmap-Parser>.
 It contains the latest developments on the module. The nmap security scanner
 homepage can be found at: L<http://www.insecure.org/nmap/>.
 
@@ -1909,7 +1928,7 @@ Origiinal author, Anthony Persaud L<https://www.modernistik.com>. However, speci
 Please see Changes file and CONTRIBUTORS file for a list of other great contributors.
 
 =head1 COPYRIGHT
-Copyright (c) <2003-2013> <Anthony Persaud> L<https://www.modernistik.com>
+Copyright (c) <2003-2017> <Anthony Persaud> L<https://www.modernistik.com>
 
 MIT License
 
